#!/etc/opt/openit/perl

# Adds the Mapping:rename-software-id filter to all licenseevents filter files (process is placed after Threshold:zero-duration filter).


my $filter_dir = "/var/opt/openit/etc/filtrator";
my @licenseevents_filters = get_filters_to_update();

foreach my $file ( @licenseevents_filters ) {
	update_filter( $filter_dir . "/" . $file );
}


sub get_filters_to_update {
	my @temp_filters = glob( "$filter_dir" );
	opendir( DIR, $filter_dir );
	@temp_filters = readdir( DIR );
	closedir( DIR );
	
	@temp_filters = grep { /\.conf$/ } @temp_filters;
	@temp_filters = grep { !/old/ } @temp_filters;
	@temp_filters = grep { /^licenseevents-|-licenseevents/ } @temp_filters;

	return @temp_filters;
}

sub update_filter {
	my ( $filter ) = @_;

	if( ! -e $filter ) {
		print "Failed to detect $filter! Script now exiting...\n";
		exit;
	}

	print "Reading '$filter' ...\n";

	open( FILE, $filter );
	my @lines = <FILE>;
	close( FILE );

	# Check if this filter has already been updated
	if( grep { /Mapping:rename-software-id/ } @lines ) {
		print "'$filter' is already updated\n";
		return;
	}

	my @new_filter_process = (
		"\t\t\tMapping:rename-software-id()=\"\"\n",
		"\t\t\t{\n"
	);
	my @new_filter_def = (
		"\t\tMapping:rename-software-id()=\"\"\n",
		"\t\t{\n",
		"\t\t\tinactive(Bool)=\"false\"{}\n",
		"\t\t\tfilter(String)=\"Mapping\"{}\n",
		"\t\t\tmap-file(FileName)=\"\${OpeniT.directories.conf}softwareid-to-feature_name.map\"{}\n",
		"\t\t\tsource(String)=\"var4\"{}\n",
		"\t\t\ttarget(String)=\"feature\"{}\n",
		"\t\t\tset-value(String)=\"#1:var4=\$feature . '\\\\' . \$product\"{}\n",
		"\t\t}\n"
	);

	my $index = 0;

	# Inserting new filter process here (for DTs 89 to 91, we insert the new filter as the first in the filter process)
	if( $filter =~ /-licenseevents/ ) {
		$index++ while( $lines[$index] !~ /filter-process/ );
	}
	else {
		$index++ while( $lines[$index] !~ /Threshold/ );
	}
	$index += 2;
	splice @lines, $index, 0, @new_filter_process;
	$index++ while( $lines[$index] !~ /filter-defs/ );
	if( $filter =~ /-licenseevents/ ) {
		splice @lines, $index - 2, 0, "\t\t}\n";
	}
	else {
		splice @lines, $index - 3, 0, "\t\t\t}\n";
	}
	
	# Inserting new filter definition here
	$index++ while( $lines[$index] !~ /filter-defs/ );
	$index += 2;
	splice @lines, $index, 0, @new_filter_def;
	
	backup_filter( $filter );

	# Write new filter file
	open( OUT, ">$filter" );
	print OUT @lines;
	close( OUT );
	print "$filter successfully updated!\n";
}

sub backup_filter {
	my ( $filter ) = @_;
	
	print "Creating $filter backup ...\n";

	rename( $filter, $filter . ".old_2125" );
}
