#!/etc/opt/openit/perl

# Applies the following updates:
#
# DT 91 (licenseevents-usergroups)
# - Add "duration" before "elapsed_time" in Summarize:license-usage "summarize"
# - Add "inactive(Bool)="false"{}" in Mapping:rename-zero-group
#
# DT 109 (licenseevents-hostgroups)
# - Remove "primetime" in Concurrent:feature "compare"


my $dt91_filter = "/var/opt/openit/etc/filtrator/licenseevents-usergroups.conf";
my $dt109_filter = "/var/opt/openit/etc/filtrator/licenseevents-hostgroups.conf";

my @dt91_lines = _read_file( $dt91_filter );
my @dt109_lines = _read_file( $dt109_filter );

my $ind = 0;


# Fix DT 91 filter
$ind = locateLine( $ind , "filter-defs" , \@dt91_lines );
$ind = locateLine( $ind , "Summarize.license-usage" , \@dt91_lines );
$ind = locateLine( $ind , "summarize" , \@dt91_lines );

if ( $ind != 0 )
{
	if( @dt91_lines[$ind] !~ /duration,elapsed_time/ )
	{
		@dt91_lines[$ind] =~ s/elapsed_time/duration,elapsed_time/;
		print( "-- Added \"duration\" in licenseevents-usergroups Summarize:license-usage -> summarize\n" );
	}
}

$ind = 0;
$ind = locateLine( $ind , "filter-defs" , \@dt91_lines );
$ind = locateLine( $ind , "Mapping.rename-zero-group" , \@dt91_lines );

if( $ind != 0 )
{
	$ind++;
	@dt91_lines[$ind] =~ s/\{/\{\n\t\t\tinactive(Bool)=\"false\"\{\}\n/;
	print( "-- Added \"inactive\" subobject in licenseevents-usergroups Mapping:rename-zero-group\n" );
}


# Fix DT 109 filter
$ind = 0;
$ind = locateLine( $ind , "filter-defs" , \@dt109_lines );
$ind = locateLine( $ind , "Concurrent.feature" , \@dt109_lines );
$ind = locateLine( $ind , "compare" , \@dt109_lines );

if( $ind != 0 )
{
	if( @dt109_lines[$ind] =~ /primetime/ )
	{
		@dt109_lines[$ind] =~ s/,primetime//;
		print( "-- Removed \"primetime\" column from Concurrent:feature -> compare\n" );
	}
}


_save_filter( $dt91_filter , @dt91_lines );
print( "-- Done updating LicenseEvents Usergroups filters\n" );
_save_filter( $dt109_filter , @dt109_lines );
print( "-- Done updating LicenseEvents Hostgroups filter\n" );

exit( 0 ); 


sub _save_filter
{
	my ( $cfg, @lines ) = @_; 
	
	my $old = "$cfg.pre_2125";
	my $new = "$cfg.new";
	
	open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
	print OUT @lines;
	close(OUT);

	if( ! rename($cfg, $old)) {
		die "Error: Unable to previous config to '$old'!\n";
	}

	if( ! rename($new, $cfg)) {
		die "Error: Unable to rename new config to '$cfg'!\n";
	}
}


sub locateLine{
	my ( $start , $find , $lines_ref ) = (@_);
	
	my ( $index )= grep { @$lines_ref[$_] =~ /$find/ } $start ..@$lines_ref;
	
	return $index;
}

sub _read_file
{
	my ($cfg) = @_;
	open(IN, "$cfg") || die "Error: Unable to read cfg '$cfg'!\n";
	my @lines = <IN>;
	close(IN);
	return @lines;
}
